<?php

// Exit if accessed directly.
if (!defined('ABSPATH')) {
    exit;
}

class VantevoAnalytics
{

    public function __construct()
    {



        add_action('wp_enqueue_scripts', [$this, 'add_vantevo_script_header']);

        add_filter('script_loader_tag',  [$this, 'add_vantevo_attributes'], 10, 2);
    }


    public static function vantevo_starts_with($haystack, $needle)
    {
        $length = strlen($needle);
        return substr($haystack, 0, $length) === $needle;
    }


    public static function vantevo_ends_with($haystack, $needle)
    {
        $length = strlen($needle);
        if (!$length) {
            return true;
        }
        return substr($haystack, -$length) === $needle;
    }

    /**
     * 
     * verify valid domain
     * 
     */
    public function is_valid_domain_name($domain_name)
    {
        return (preg_match("/^([a-z\d](-*[a-z\d])*)(\.([a-z\d](-*[a-z\d])*))*$/i", $domain_name) //valid chars check
            && preg_match("/^.{1,253}$/", $domain_name) //overall length check
            && preg_match("/^[^\.]{1,63}(\.[^\.]{1,63})*$/", $domain_name)); //length of each label
    }

    /**
     * 
     * add script vantevo to header
     * 
     */
    public function add_vantevo_script_header()
    {

        $src = "https://vantevo.io/js/vantevo.js?ver";

        //add vantevo script 
        wp_enqueue_script("vantevo-analytics",  $src, [], VANTEVO_VERSION, false);


        //register window.vantevo 
        wp_add_inline_script('vantevo-analytics', 'window.vantevo = window.vantevo || function() { (window.vantevo.data = window.vantevo.data || []).push(arguments) };');


        //404 page not found
        if (is_404() && get_option('vantevo_option_404') == "OK") {
            wp_add_inline_script('vantevo-analytics', 'window.vantevo("404");');
        }
    }

   

    /**
     * 
     * add attributes script vantevo
     * 
     */
    public function add_vantevo_attributes($tag, $handle)
    {

        if ('vantevo-analytics' !== $handle) {
            return $tag;
        }

        //Development mode
        if (get_option('vantevo_option_dev') == "OK") {
            $tag = str_replace(' src', " data-param-dev src", $tag);
        }
        //Hash mode
        if (get_option('vantevo_option_hash') == "OK") {
            $tag = str_replace(' src', " data-param-hash src", $tag);
        }

        //Esclude pages
        $exclude_pages = get_option('vantevo_option_exclude');
        if ($exclude_pages) {
            $tag = str_replace(' src', " data-param-exclude='" . esc_html($exclude_pages) . "' src", $tag);
        }

        //manual pageview
        if (get_option('vantevo_option_manual_pageview') == "OK") {
            $tag = str_replace(' src', " data-param-manual-pageview src", $tag);
        }

        //outbound links
        if (get_option('vantevo_option_outbound_link') == "OK") {
            $tag = str_replace(' src', " data-param-outbound-links src", $tag);
        }

         //tracking files
         $extensions = get_option('vantevo_option_track_files');
         if (get_option('vantevo_option_track_files')) {
            $tag = str_replace(' src', " data-param-track-files='" . esc_html($extensions) . "' src", $tag);
         }

         //tracking extensions files
        if (get_option('vantevo_option_track_extension') == "OK") {
            $tag = str_replace(' src', " data-param-save-extension src", $tag);
        }

        //domain
        $domain = get_option('vantevo_option_domain');
        if ($domain && $this->is_valid_domain_name($domain)) {
            $tag = str_replace(' src', " data-param-domain='" . esc_html($domain) . "' src", $tag);
        }

        //add paramters script vantevo-analytics && defer attributes
        return str_replace(' src', " defer src", $tag);
    }
}
